/****************************************************************************
** Meta object code from reading C++ file 'ktextedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ktextwidgets-6.28.0/src/widgets/ktextedit.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktextedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KTextEditE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEdit::qt_create_metaobjectdata<qt_meta_tag_ZN9KTextEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEdit",
        "checkSpellingChanged",
        "",
        "spellCheckStatus",
        "languageChanged",
        "language",
        "aboutToShowContextMenu",
        "QMenu*",
        "menu",
        "spellCheckerAutoCorrect",
        "currentWord",
        "autoCorrectWord",
        "spellCheckingFinished",
        "spellCheckingCanceled",
        "setSpellCheckingLanguage",
        "checkSpelling",
        "showSpellConfigDialog",
        "windowIcon",
        "replace",
        "addTextDecorator",
        "Sonnet::SpellCheckDecorator*",
        "decorator",
        "clearDecorator",
        "slotDoReplace",
        "slotReplaceNext",
        "slotDoFind",
        "slotFind",
        "slotFindNext",
        "slotFindPrevious",
        "slotReplace",
        "slotSpeakText",
        "checkSpellingEnabled",
        "spellCheckingLanguage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkSpellingChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'spellCheckStatus'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'languageChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'aboutToShowContextMenu'
        QtMocHelpers::SignalData<void(QMenu *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'spellCheckerAutoCorrect'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'spellCheckingFinished'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spellCheckingCanceled'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSpellCheckingLanguage'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'checkSpelling'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSpellConfigDialog'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'showSpellConfigDialog'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'replace'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addTextDecorator'
        QtMocHelpers::SlotData<void(Sonnet::SpellCheckDecorator *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'clearDecorator'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDoReplace'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotReplaceNext'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDoFind'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFindNext'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFindPrevious'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotReplace'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSpeakText'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'checkSpellingEnabled'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'spellCheckingLanguage'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTextEdit, qt_meta_tag_ZN9KTextEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KTextEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KTextEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KTextEditE_t>.metaTypes,
    nullptr
} };

void KTextEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTextEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkSpellingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->spellCheckStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->languageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->aboutToShowContextMenu((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 4: _t->spellCheckerAutoCorrect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->spellCheckingFinished(); break;
        case 6: _t->spellCheckingCanceled(); break;
        case 7: _t->setSpellCheckingLanguage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->checkSpelling(); break;
        case 9: _t->showSpellConfigDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->showSpellConfigDialog(); break;
        case 11: _t->replace(); break;
        case 12: _t->addTextDecorator((*reinterpret_cast<std::add_pointer_t<Sonnet::SpellCheckDecorator*>>(_a[1]))); break;
        case 13: _t->clearDecorator(); break;
        case 14: _t->slotDoReplace(); break;
        case 15: _t->slotReplaceNext(); break;
        case 16: _t->slotDoFind(); break;
        case 17: _t->slotFind(); break;
        case 18: _t->slotFindNext(); break;
        case 19: _t->slotFindPrevious(); break;
        case 20: _t->slotReplace(); break;
        case 21: _t->slotSpeakText(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)(bool )>(_a, &KTextEdit::checkSpellingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)(const QString & )>(_a, &KTextEdit::spellCheckStatus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)(const QString & )>(_a, &KTextEdit::languageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)(QMenu * )>(_a, &KTextEdit::aboutToShowContextMenu, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)(const QString & , const QString & )>(_a, &KTextEdit::spellCheckerAutoCorrect, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)()>(_a, &KTextEdit::spellCheckingFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KTextEdit::*)()>(_a, &KTextEdit::spellCheckingCanceled, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->checkSpellingEnabled(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->spellCheckingLanguage(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCheckSpellingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setSpellCheckingLanguage(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KTextEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KTextEditE_t>.strings))
        return static_cast<void*>(this);
    return QTextEdit::qt_metacast(_clname);
}

int KTextEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KTextEdit::checkSpellingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KTextEdit::spellCheckStatus(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KTextEdit::languageChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KTextEdit::aboutToShowContextMenu(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KTextEdit::spellCheckerAutoCorrect(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KTextEdit::spellCheckingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KTextEdit::spellCheckingCanceled()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
