// DO NOT EDIT! Generated from ecm_add_qtdesignerplugin()

#include <QDesignerCustomWidgetCollectionInterface>
#include <QDesignerCustomWidgetInterface>
#include <QObject>
#include <QIcon>
#include <QString>
#include <krichtextedit.h>
#include <krichtextwidget.h>
#include <ktextedit.h>
#include <kpluralhandlingspinbox.h>

class KRichTextEditQtDesignerWidgetFactory
    : public QObject
    , public QDesignerCustomWidgetInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetInterface)

public:
    explicit KRichTextEditQtDesignerWidgetFactory(QObject *parent = nullptr)
        : QObject(parent)
        , m_initialized(false)
    {}

    ~KRichTextEditQtDesignerWidgetFactory() override {}
    
public: // QDesignerCustomWidgetInterface API
    bool isInitialized() const override { return m_initialized; }

    bool isContainer() const override { return false; }
    QIcon icon() const override { return QIcon(); }
    QString group() const override { return QStringLiteral("Input (KF6)"); }
    QString includeFile() const override { return QStringLiteral("krichtextedit.h"); }
    QString name() const override { return QStringLiteral("KRichTextEdit"); }
    QString toolTip() const override { return QStringLiteral("Rich Text Editor (KF6)"); }
    QString whatsThis() const override { return QStringLiteral("Rich Text Editor (KF6)"); }

    QWidget* createWidget(QWidget* parent) override
    {
        return new KRichTextEdit(parent);
    }

    void initialize(QDesignerFormEditorInterface* core) override 
    {
        Q_UNUSED(core);

        if (m_initialized) return;

        m_initialized = true;
    }

private:
    bool m_initialized;
};

class KRichTextWidgetQtDesignerWidgetFactory
    : public QObject
    , public QDesignerCustomWidgetInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetInterface)

public:
    explicit KRichTextWidgetQtDesignerWidgetFactory(QObject *parent = nullptr)
        : QObject(parent)
        , m_initialized(false)
    {}

    ~KRichTextWidgetQtDesignerWidgetFactory() override {}
    
public: // QDesignerCustomWidgetInterface API
    bool isInitialized() const override { return m_initialized; }

    bool isContainer() const override { return false; }
    QIcon icon() const override { return QIcon(); }
    QString group() const override { return QStringLiteral("Input (KF6)"); }
    QString includeFile() const override { return QStringLiteral("krichtextwidget.h"); }
    QString name() const override { return QStringLiteral("KRichTextWidget"); }
    QString toolTip() const override { return QStringLiteral("Rich Text Widget (KF6)"); }
    QString whatsThis() const override { return QStringLiteral("Rich Text Widget (KF6)"); }

    QWidget* createWidget(QWidget* parent) override
    {
        return new KRichTextWidget(parent);
    }

    void initialize(QDesignerFormEditorInterface* core) override 
    {
        Q_UNUSED(core);

        if (m_initialized) return;

        m_initialized = true;
    }

private:
    bool m_initialized;
};

class KTextEditQtDesignerWidgetFactory
    : public QObject
    , public QDesignerCustomWidgetInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetInterface)

public:
    explicit KTextEditQtDesignerWidgetFactory(QObject *parent = nullptr)
        : QObject(parent)
        , m_initialized(false)
    {}

    ~KTextEditQtDesignerWidgetFactory() override {}
    
public: // QDesignerCustomWidgetInterface API
    bool isInitialized() const override { return m_initialized; }

    bool isContainer() const override { return false; }
    QIcon icon() const override { return QIcon(QStringLiteral(":/KTextWidgetsWidgets/designer/ktextedit.png")); }
    QString group() const override { return QStringLiteral("Input (KF6)"); }
    QString includeFile() const override { return QStringLiteral("ktextedit.h"); }
    QString name() const override { return QStringLiteral("KTextEdit"); }
    QString toolTip() const override { return QStringLiteral("Improved QTextEdit (KF6)"); }
    QString whatsThis() const override { return QStringLiteral("An improved version of the QTextEdit with mail or system browser invocation support"); }

    QWidget* createWidget(QWidget* parent) override
    {
        return new KTextEdit(parent);
    }

    void initialize(QDesignerFormEditorInterface* core) override 
    {
        Q_UNUSED(core);

        if (m_initialized) return;

        m_initialized = true;
    }

private:
    bool m_initialized;
};

class KPluralHandlingSpinBoxQtDesignerWidgetFactory
    : public QObject
    , public QDesignerCustomWidgetInterface
{
    Q_OBJECT
    Q_INTERFACES(QDesignerCustomWidgetInterface)

public:
    explicit KPluralHandlingSpinBoxQtDesignerWidgetFactory(QObject *parent = nullptr)
        : QObject(parent)
        , m_initialized(false)
    {}

    ~KPluralHandlingSpinBoxQtDesignerWidgetFactory() override {}
    
public: // QDesignerCustomWidgetInterface API
    bool isInitialized() const override { return m_initialized; }

    bool isContainer() const override { return false; }
    QIcon icon() const override { return QIcon(); }
    QString group() const override { return QStringLiteral("Input (KF6)"); }
    QString includeFile() const override { return QStringLiteral("kpluralhandlingspinbox.h"); }
    QString name() const override { return QStringLiteral("KPluralHandlingSpinBox"); }
    QString toolTip() const override { return QStringLiteral("A QSpinBox with plural handling for the suffix (KF6)"); }
    QString whatsThis() const override { return QStringLiteral("A QSpinBox with plural handling for the suffix"); }

    QWidget* createWidget(QWidget* parent) override
    {
        return new KPluralHandlingSpinBox(parent);
    }

    void initialize(QDesignerFormEditorInterface* core) override 
    {
        Q_UNUSED(core);

        if (m_initialized) return;

        m_initialized = true;
    }

private:
    bool m_initialized;
};

class KTextWidgetsWidgetsQtDesignerWidgetCollection
    : public QObject
    , public QDesignerCustomWidgetCollectionInterface
{
    Q_OBJECT
    Q_INTERFACES(
        QDesignerCustomWidgetCollectionInterface
    )

    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QDesignerCustomWidgetCollectionInterface")

public:
    explicit KTextWidgetsWidgetsQtDesignerWidgetCollection(QObject* parent = nullptr);

public: // QDesignerCustomWidgetCollectionInterface API
    QList<QDesignerCustomWidgetInterface*> customWidgets() const override;

private:
    QList<QDesignerCustomWidgetInterface*> m_widgetFactories;
};

KTextWidgetsWidgetsQtDesignerWidgetCollection::KTextWidgetsWidgetsQtDesignerWidgetCollection(QObject* parent)
    : QObject(parent)
{
    m_widgetFactories = QList<QDesignerCustomWidgetInterface*>{
        new KRichTextEditQtDesignerWidgetFactory(this),
        new KRichTextWidgetQtDesignerWidgetFactory(this),
        new KTextEditQtDesignerWidgetFactory(this),
        new KPluralHandlingSpinBoxQtDesignerWidgetFactory(this),
    };
}

QList<QDesignerCustomWidgetInterface*> KTextWidgetsWidgetsQtDesignerWidgetCollection::customWidgets() const
{
    return m_widgetFactories;
}

#include "designerplugin.moc"
